# pyostrap
Python wrapper for Biostrap API

## Installing Pyostrap and Supported Versions

Pyostrap is available on PyPI:

```console
$ pip install pyostrap
```

Pyostrap officially supports Python 3.12+ and HTTP/2 protocol.

### Dependencies

Pyostrap project utilizes the httpx library - the HTTP client library for Python 3.

## Release Information
- `2025.04.11.0` added support for HTTP/2 protocol (#20)
- `2024.11.12.2` added granularity in user steps data retrieved (#16)
- `2024.11.4.7` implemented biometrics endpoint (#2)
- `2024.6.20.2` implemented lock/unlock device and user calories details endpoints (#3, #10)
